@@ -17,13 +17,7 @@
 #include <stdarg.h>
 #include <RcppArmadillo.h>
 #include <R.h>
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext ("rxode2", String)
-/* replace pkg as appropriate */
-#else
 #define _(String) (String)
-#endif
 
 extern "C" double gamma_p(double a, double z) {
   return boost::math::gamma_p<double, double>(a, z);
