@@ -9,13 +9,7 @@
 #include <Rcpp.h>
 using namespace Rcpp;
 
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext ("rxode2", String)
-/* replace pkg as appropriate */
-#else
 #define _(String) (String)
-#endif
 bool rxIs(const RObject &obj, std::string cls);
 Function getRxFn(std::string name);
 
