@@ -1,15 +1,10 @@
 rxTest({
   test_that("assert properties of rxUi models", {
-
     one.cmt <- function() {
       ini({
-        ## You may label each parameter with a comment
-        tka <- 0.45 # Ka
-        tcl <- log(c(0, 2.7, 100)) # Log Cl
-        ## This works with interactive models
-        ## You may also label the preceding line with label("label text")
-        tv <- 3.45; label("log V")
-        ## the label("Label name") works with all models
+        tka <- 0.45
+        tcl <- log(c(0, 2.7, 100))
+        tv <- 3.45
         eta.ka ~ 0.6
         eta.cl ~ 0.3
         eta.v ~ 0.1
@@ -29,25 +24,24 @@ rxTest({
         tka <- log(1)
         tcl <- log(0.1)
         tv <- log(10)
-        ##
+
         eta.ktr ~ 1
         eta.ka ~ 1
         eta.cl ~ 2
         eta.v ~ 1
         prop.err <- 0.1
         pkadd.err <- 0.1
-        ##
+
         temax <- logit(0.8)
-        #temax <- 7.5
         tec50 <- log(0.5)
         tkout <- log(0.05)
         te0 <- log(100)
-        ##
+
         eta.emax ~ .5
         eta.ec50  ~ .5
         eta.kout ~ .5
         eta.e0 ~ .5
-        ##
+
         pdadd.err <- 10
       })
       model({
@@ -80,8 +74,12 @@ rxTest({
       })
     }
 
-    expect_error(assertRxUi(rnorm))
-
+    suppressMessages(
+      expect_error(
+        assertRxUi(rnorm),
+        "needs to be a rxUi model"
+      )
+    )
     expect_error(assertRxUi(one.cmt), NA)
 
     expect_error(assertRxUiSingleEndpoint(pk.turnover.emax))
@@ -94,13 +92,9 @@ rxTest({
 
     one.cmt.t <- function() {
       ini({
-        ## You may label each parameter with a comment
-        tka <- 0.45 # Ka
-        tcl <- log(c(0, 2.7, 100)) # Log Cl
-        ## This works with interactive models
-        ## You may also label the preceding line with label("label text")
-        tv <- 3.45; label("log V")
-        ## the label("Label name") works with all models
+        tka <- 0.45
+        tcl <- log(c(0, 2.7, 100))
+        tv <- 3.45
         eta.ka ~ 0.6
         eta.cl ~ 0.3
         eta.v ~ 0.1
@@ -123,13 +117,9 @@ rxTest({
 
     one.cmt.t.est <- function() {
       ini({
-        ## You may label each parameter with a comment
-        tka <- 0.45 # Ka
-        tcl <- log(c(0, 2.7, 100)) # Log Cl
-        ## This works with interactive models
-        ## You may also label the preceding line with label("label text")
-        tv <- 3.45; label("log V")
-        ## the label("Label name") works with all models
+        tka <- 0.45
+        tcl <- log(c(0, 2.7, 100))
+        tv <- 3.45
         eta.ka ~ 0.6
         eta.cl ~ 0.3
         eta.v ~ 0.1
@@ -152,13 +142,9 @@ rxTest({
 
     one.cmt.pop <- function() {
       ini({
-        ## You may label each parameter with a comment
-        tka <- 0.45 # Ka
-        tcl <- log(c(0, 2.7, 100)) # Log Cl
-        ## This works with interactive models
-        ## You may also label the preceding line with label("label text")
-        tv <- 3.45; label("log V")
-        ## the label("Label name") works with all models
+        tka <- 0.45
+        tcl <- log(c(0, 2.7, 100))
+        tv <- 3.45
         add.sd <- 0.7
         nu <- 3
       })
@@ -172,12 +158,9 @@ rxTest({
 
     expect_error(assertRxUiMixedOnly(one.cmt.pop))
     expect_error(assertRxUiPopulationOnly(one.cmt.pop), NA)
-
-
   })
 
   test_that("There must be at least one prediction assertion", {
-
     uif <- function() {
       ini({
         tka <- 4
@@ -203,21 +186,14 @@ rxTest({
       assertRxUiPrediction(tmp),
       regexp="there must be at least one prediction"
     )
-
-
   })
 
   test_that("Transformably and non-transformably normal", {
-
     one.cmt <- function() {
       ini({
-        ## You may label each parameter with a comment
-        tka <- 0.45 # Ka
-        tcl <- log(c(0, 2.7, 100)) # Log Cl
-        ## This works with interactive models
-        ## You may also label the preceding line with label("label text")
-        tv <- 3.45; label("log V")
-        ## the label("Label name") works with all models
+        tka <- 0.45
+        tcl <- log(c(0, 2.7, 100))
+        tv <- 3.45
         eta.ka ~ 0.6
         eta.cl ~ 0.3
         eta.v ~ 0.1
@@ -234,21 +210,14 @@ rxTest({
 
     expect_error(assertRxUiNormal(one.cmt))
     expect_error(assertRxUiTransformNormal(one.cmt), NA)
-
   })
 
-
   test_that("mu ref only", {
-
     one.cmt <- function() {
       ini({
-        ## You may label each parameter with a comment
-        tka <- 0.45 # Ka
-        tcl <- log(c(0, 2.7, 100)) # Log Cl
-        ## This works with interactive models
-        ## You may also label the preceding line with label("label text")
-        tv <- 3.45; label("log V")
-        ## the label("Label name") works with all models
+        tka <- 0.45
+        tcl <- log(c(0, 2.7, 100))
+        tv <- 3.45
         eta.ka ~ 0.6
         eta.cl ~ 0.3
         eta.v ~ 0.1
@@ -267,13 +236,9 @@ rxTest({
 
     one.cmt <- function() {
       ini({
-        ## You may label each parameter with a comment
-        tka <- 0.45 # Ka
-        tcl <- log(c(0, 2.7, 100)) # Log Cl
-        ## This works with interactive models
-        ## You may also label the preceding line with label("label text")
-        tv <- 3.45; label("log V")
-        ## the label("Label name") works with all models
+        tka <- 0.45
+        tcl <- log(c(0, 2.7, 100))
+        tv <- 3.45
         eta.ka ~ 0.6
         eta.cl ~ 0.3
         eta.v ~ 0.1
@@ -290,16 +255,11 @@ rxTest({
 
     expect_error(assertRxUiMuRefOnly(one.cmt))
 
-
     one.cmt <- function() {
       ini({
-        ## You may label each parameter with a comment
-        tka <- 0.45 # Ka
-        tcl <- log(c(0, 2.7, 100)) # Log Cl
-        ## This works with interactive models
-        ## You may also label the preceding line with label("label text")
-        tv <- 3.45; label("log V")
-        ## the label("Label name") works with all models
+        tka <- 0.45
+        tcl <- log(c(0, 2.7, 100))
+        tv <- 3.45
         eta.ka ~ 0.6 | occ
         eta.cl ~ 0.3
         eta.v ~ 0.1
@@ -313,7 +273,12 @@ rxTest({
       })
     }
 
-    expect_error(assertRxUiRandomOnIdOnly(one.cmt))
-
+    expect_warning(
+      expect_error(
+        assertRxUiRandomOnIdOnly(one.cmt),
+        regexp = "can only have random effects on ID"
+      ),
+      regexp = "some etas defaulted to non-mu referenced"
+    )
   })
 })
